@@ -1,5 +1,5 @@
 #-*- encoding: utf-8 -*-
-VERSION='0.3.8-a'
+VERSION='0.3.9'
 MAX_RETRIES=5
 import sys
 try:
@@ -102,8 +102,7 @@ class M3UPlaylist(object):
             for newMatch in range(bestMatch, -1, -1):
                 if(isInPlaylist(newMatch)):
                     bestMatch = newMatch
-                else:
-                    break
+
             return self.playlist[Keys.QUALITY_LIST_STREAM[bestMatch]]
 
     def __str__(self):
